@@ -190,27 +190,27 @@ async fn main() -> Result<()> {
         .setting(AppSettings::DeriveDisplayOrder)
         .setting(AppSettings::SubcommandsNegateReqs)
         .arg(
-            Arg::with_name("FULLHELP")
+            Arg::new("FULLHELP")
                 .help("Prints more detailed help information")
                 .long("fullhelp"),
         )
         .arg(
-            Arg::with_name("debug")
+            Arg::new("debug")
                 .long("debug")
-                .short("d")
+                .short('d')
                 .help("Prints debug log information"),
         )
         .arg(
-            Arg::with_name("offer-address")
-                .required_unless("FULLHELP")
+            Arg::new("offer-address")
+                .required_unless_present("FULLHELP")
                 .takes_value(true)
                 .default_value("localhost:50000")
                 .long("offer-address")
                 .help("Address that the Offer HTTP server is hosted on."),
         )
         .arg(
-            Arg::with_name("answer-address")
-                .required_unless("FULLHELP")
+            Arg::new("answer-address")
+                .required_unless_present("FULLHELP")
                 .takes_value(true)
                 .default_value("0.0.0.0:60000")
                 .long("answer-address")
@@ -266,7 +266,7 @@ async fn main() -> Result<()> {
     let mut registry = Registry::new();
 
     // Use the default set of Interceptors
-    registry = register_default_interceptors(registry, &mut m).await?;
+    registry = register_default_interceptors(registry, &mut m)?;
 
     // Create the API object with the MediaEngine
     let api = APIBuilder::new()
