@@ -30,24 +30,24 @@ async fn main() -> Result<()> {
         .setting(AppSettings::DeriveDisplayOrder)
         .setting(AppSettings::SubcommandsNegateReqs)
         .arg(
-            Arg::with_name("FULLHELP")
+            Arg::new("FULLHELP")
                 .help("Prints more detailed help information")
                 .long("fullhelp"),
         )
         .arg(
-            Arg::with_name("debug")
+            Arg::new("debug")
                 .long("debug")
-                .short("d")
+                .short('d')
                 .help("Prints debug log information"),
         ).arg(
-            Arg::with_name("audio")
+            Arg::new("audio")
                 .long("audio")
-                .short("a")
+                .short('a')
                 .help("Enable audio reflect"),
         ).arg(
-            Arg::with_name("video")
+            Arg::new("video")
                 .long("video")
-                .short("v")
+                .short('v')
                 .help("Enable video reflect"),
         );
 
@@ -127,7 +127,7 @@ async fn main() -> Result<()> {
     let mut registry = Registry::new();
 
     // Use the default set of Interceptors
-    registry = register_default_interceptors(registry, &mut m).await?;
+    registry = register_default_interceptors(registry, &mut m)?;
 
     // Create the API object with the MediaEngine
     let api = APIBuilder::new()
