@@ -66,34 +66,34 @@ async fn main() -> Result<()> {
         .setting(AppSettings::DeriveDisplayOrder)
         .setting(AppSettings::SubcommandsNegateReqs)
         .arg(
-            Arg::with_name("FULLHELP")
+            Arg::new("FULLHELP")
                 .help("Prints more detailed help information")
                 .long("fullhelp"),
         )
         .arg(
-            Arg::with_name("debug")
+            Arg::new("debug")
                 .long("debug")
-                .short("d")
+                .short('d')
                 .help("Prints debug log information"),
         )
         .arg(
-            Arg::with_name("vp9")
+            Arg::new("vp9")
                 .long("vp9")
                 .help("Save VP9 to disk. Default: VP8"),
         )
         .arg(
-            Arg::with_name("video")
-                .required_unless("FULLHELP")
+            Arg::new("video")
+                .required_unless_present("FULLHELP")
                 .takes_value(true)
-                .short("v")
+                .short('v')
                 .long("video")
                 .help("Video file to be streaming."),
         )
         .arg(
-            Arg::with_name("audio")
-                .required_unless("FULLHELP")
+            Arg::new("audio")
+                .required_unless_present("FULLHELP")
                 .takes_value(true)
-                .short("a")
+                .short('a')
                 .long("audio")
                 .help("Audio file to be streaming."),
         );
@@ -195,7 +195,7 @@ async fn main() -> Result<()> {
     let mut registry = Registry::new();
 
     // Use the default set of Interceptors
-    registry = register_default_interceptors(registry, &mut m).await?;
+    registry = register_default_interceptors(registry, &mut m)?;
 
     // Create the API object with the MediaEngine
     let api = APIBuilder::new()
